@@ -16,4 +16,6 @@
 # You should have received a copy of the GNU General Public License
 # along with fadge.  If not, see <http://www.gnu.org/licenses/>.
 
-from . import metric, geode, utils, viz
+
+from . import bounds, geode, icond, metric, shadow, utils, viz
+from .core import GRRT
